@@ -3,6 +3,14 @@ import pandas as pd
 import numpy as np
 
 def identifier_conversion(input_type, compound_list):
+    """
+    Use Metaboanalyst API for identifier conversion
+    Args:
+        input_type (str): identifier type present in input data - any of ('name', 'hmdb', 'pubchem', 'chebi', 'metlin', 'kegg')
+        compound_list (list): list of identifiers in the data
+    Returns:
+        (pd.DataFrame) Dataframe containing identifier matches 
+    """
     url = "http://api.xialab.ca/mapcompounds"
 
     resps = []
@@ -25,6 +33,17 @@ def identifier_conversion(input_type, compound_list):
     return resp_df
 
 def map_identifiers(query_df, output_id_type, matrix):
+    """
+    Map desired identifiers to input data
+    Args:
+        query_df (pd.DataFrame): DataFrame obtained using the identifier_conversion function containing ID mappings
+        output_id_type (str): Any of ('name', 'hmdb', 'pubchem', 'chebi', 'metlin', 'kegg')
+        matrix (pd.DataFrame): sample-by-compound metabolomics data matrix
+    Returns:
+        Sample-by-compound metabolomics data matrix with mapped identifiers, any compounds without a matching ID will be dropped
+    """
+
+
     # output id type can be any of ['HMDB', 'PubChem', 'ChEBI', 'KEGG', 'METLIN','SMILES']
     cpd_mapping_dict = dict(zip(query_df["Query"].tolist(), query_df[output_id_type].tolist()))
     cpd_mapping_dict = {k: v for k, v in cpd_mapping_dict.items() if v not in ["NA", np.nan, None, "None"]}
