@@ -7,13 +7,15 @@ def sspa_kpca(mat, pathway_df, min_entity=2):
     """
     Kernel PCA method for single sample pathway analysis
 
-    :param mat: pandas DataFrame omics data matrix consisting of m rows (samples) and n columns (entities).
-    Do not include metadata columns
-    :param pathways: Dictionary of pathway identifiers (keys) and corresponding list of pathway entities (values).
-    Entity identifiers must match those in the matrix columns
-    :param min_entity: Minimum number of entities present in the dataset in a pathway to perform the analysis. Default is 2.
+    Args:
+        mat (pd.DataFrame): pandas DataFrame omics data matrix consisting of m rows (samples) and n columns (entities).
+        Do not include metadata columns
+        pathways (pd.DataFrame): Dictionary of pathway identifiers (keys) and corresponding list of pathway entities (values).
+        Entity identifiers must match those in the matrix columns
+        min_entity (int): minimum number of metabolites mapping to pathways for ssPA to be performed
 
-    :return: pandas DataFrame of pathway scores derived using the kPCA method. Columns represent pathways and rows represnt samples.
+    Returns:
+        pandas DataFrame of pathway scores derived using the kPCA method. Columns represent pathways and rows represent samples.
     """
 
     pathways = utils.pathwaydf_to_dict(pathway_df)
